# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'mainwindow.ui'
##
## Created by: Qt User Interface Compiler version 6.4.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QAction, QBrush, QColor, QConicalGradient,
    QCursor, QFont, QFontDatabase, QGradient,
    QIcon, QImage, QKeySequence, QLinearGradient,
    QPainter, QPalette, QPixmap, QRadialGradient,
    QTransform)
from PySide6.QtWidgets import (QApplication, QCheckBox, QComboBox, QFrame,
    QLabel, QLineEdit, QMainWindow, QMenu,
    QMenuBar, QPlainTextEdit, QProgressBar, QPushButton,
    QRadioButton, QSizePolicy, QStatusBar, QTextEdit,
    QWidget)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(580, 595)
        self.actionE_V = QAction(MainWindow)
        self.actionE_V.setObjectName(u"actionE_V")
        self.actionasasas = QAction(MainWindow)
        self.actionasasas.setObjectName(u"actionasasas")
        self.actionEV = QAction(MainWindow)
        self.actionEV.setObjectName(u"actionEV")
        self.actionSUMMARY = QAction(MainWindow)
        self.actionSUMMARY.setObjectName(u"actionSUMMARY")
        self.actionOUTCAR = QAction(MainWindow)
        self.actionOUTCAR.setObjectName(u"actionOUTCAR")
        self.actionDOSCAR = QAction(MainWindow)
        self.actionDOSCAR.setObjectName(u"actionDOSCAR")
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.lineEdit = QLineEdit(self.centralwidget)
        self.lineEdit.setObjectName(u"lineEdit")
        self.lineEdit.setGeometry(QRect(60, 10, 61, 24))
        self.lineEdit_xs = QLineEdit(self.centralwidget)
        self.lineEdit_xs.setObjectName(u"lineEdit_xs")
        self.lineEdit_xs.setEnabled(False)
        self.lineEdit_xs.setGeometry(QRect(140, 460, 171, 24))
        self.lineEdit_xs.setFrame(True)
        self.lineEdit_el = QLineEdit(self.centralwidget)
        self.lineEdit_el.setObjectName(u"lineEdit_el")
        self.lineEdit_el.setGeometry(QRect(172, 350, 151, 24))
        self.frame_4 = QFrame(self.centralwidget)
        self.frame_4.setObjectName(u"frame_4")
        self.frame_4.setGeometry(QRect(10, 390, 561, 101))
        self.frame_4.setFrameShape(QFrame.Box)
        self.frame_4.setFrameShadow(QFrame.Raised)
        self.pushButton = QPushButton(self.centralwidget)
        self.pushButton.setObjectName(u"pushButton")
        self.pushButton.setGeometry(QRect(260, 140, 80, 24))
        self.label_5 = QLabel(self.centralwidget)
        self.label_5.setObjectName(u"label_5")
        self.label_5.setGeometry(QRect(20, 140, 71, 21))
        self.frame_3 = QFrame(self.centralwidget)
        self.frame_3.setObjectName(u"frame_3")
        self.frame_3.setGeometry(QRect(10, 340, 561, 41))
        self.frame_3.setFrameShape(QFrame.Box)
        self.frame_3.setFrameShadow(QFrame.Raised)
        self.label_2 = QLabel(self.centralwidget)
        self.label_2.setObjectName(u"label_2")
        self.label_2.setGeometry(QRect(20, 50, 31, 16))
        self.label_7 = QLabel(self.centralwidget)
        self.label_7.setObjectName(u"label_7")
        self.label_7.setGeometry(QRect(20, 200, 121, 16))
        self.lineEdit_anh = QLineEdit(self.centralwidget)
        self.lineEdit_anh.setObjectName(u"lineEdit_anh")
        self.lineEdit_anh.setEnabled(False)
        self.lineEdit_anh.setGeometry(QRect(140, 430, 171, 24))
        self.lineEdit_anh.setFrame(True)
        self.pushButton_5 = QPushButton(self.centralwidget)
        self.pushButton_5.setObjectName(u"pushButton_5")
        self.pushButton_5.setEnabled(True)
        self.pushButton_5.setGeometry(QRect(450, 500, 80, 24))
        self.lineEdit_2 = QLineEdit(self.centralwidget)
        self.lineEdit_2.setObjectName(u"lineEdit_2")
        self.lineEdit_2.setGeometry(QRect(90, 140, 161, 24))
        self.frame_2 = QFrame(self.centralwidget)
        self.frame_2.setObjectName(u"frame_2")
        self.frame_2.setGeometry(QRect(10, 190, 561, 141))
        self.frame_2.setFrameShape(QFrame.Box)
        self.frame_2.setFrameShadow(QFrame.Raised)
        self.pushButton_2 = QPushButton(self.frame_2)
        self.pushButton_2.setObjectName(u"pushButton_2")
        self.pushButton_2.setGeometry(QRect(360, 110, 151, 24))
        self.label_9 = QLabel(self.frame_2)
        self.label_9.setObjectName(u"label_9")
        self.label_9.setGeometry(QRect(220, 30, 81, 16))
        self.lineEdit_4 = QLineEdit(self.frame_2)
        self.lineEdit_4.setObjectName(u"lineEdit_4")
        self.lineEdit_4.setGeometry(QRect(330, 30, 31, 16))
        self.label_10 = QLabel(self.frame_2)
        self.label_10.setObjectName(u"label_10")
        self.label_10.setGeometry(QRect(220, 50, 81, 16))
        self.lineEdit_5 = QLineEdit(self.frame_2)
        self.lineEdit_5.setObjectName(u"lineEdit_5")
        self.lineEdit_5.setGeometry(QRect(330, 50, 31, 16))
        self.label_11 = QLabel(self.frame_2)
        self.label_11.setObjectName(u"label_11")
        self.label_11.setGeometry(QRect(220, 70, 111, 16))
        self.lineEdit_6 = QLineEdit(self.frame_2)
        self.lineEdit_6.setObjectName(u"lineEdit_6")
        self.lineEdit_6.setGeometry(QRect(330, 70, 31, 16))
        self.elastic_constants = QTextEdit(self.frame_2)
        self.elastic_constants.setObjectName(u"elastic_constants")
        self.elastic_constants.setGeometry(QRect(10, 30, 201, 101))
        self.lineEdit_3 = QLineEdit(self.frame_2)
        self.lineEdit_3.setObjectName(u"lineEdit_3")
        self.lineEdit_3.setGeometry(QRect(500, 90, 31, 16))
        self.label_8 = QLabel(self.frame_2)
        self.label_8.setObjectName(u"label_8")
        self.label_8.setGeometry(QRect(390, 90, 81, 16))
        self.label_12 = QLabel(self.frame_2)
        self.label_12.setObjectName(u"label_12")
        self.label_12.setGeometry(QRect(390, 30, 81, 16))
        self.label_13 = QLabel(self.frame_2)
        self.label_13.setObjectName(u"label_13")
        self.label_13.setGeometry(QRect(390, 50, 81, 16))
        self.lineEdit_7 = QLineEdit(self.frame_2)
        self.lineEdit_7.setObjectName(u"lineEdit_7")
        self.lineEdit_7.setGeometry(QRect(500, 70, 31, 16))
        self.label_14 = QLabel(self.frame_2)
        self.label_14.setObjectName(u"label_14")
        self.label_14.setGeometry(QRect(390, 70, 111, 16))
        self.lineEdit_8 = QLineEdit(self.frame_2)
        self.lineEdit_8.setObjectName(u"lineEdit_8")
        self.lineEdit_8.setGeometry(QRect(500, 50, 31, 16))
        self.lineEdit_9 = QLineEdit(self.frame_2)
        self.lineEdit_9.setObjectName(u"lineEdit_9")
        self.lineEdit_9.setGeometry(QRect(500, 30, 31, 16))
        self.lineEdit_10 = QLineEdit(self.frame_2)
        self.lineEdit_10.setObjectName(u"lineEdit_10")
        self.lineEdit_10.setGeometry(QRect(330, 90, 31, 16))
        self.label_15 = QLabel(self.frame_2)
        self.label_15.setObjectName(u"label_15")
        self.label_15.setGeometry(QRect(220, 90, 111, 16))
        self.label_16 = QLabel(self.frame_2)
        self.label_16.setObjectName(u"label_16")
        self.label_16.setGeometry(QRect(360, 30, 81, 16))
        self.label_17 = QLabel(self.frame_2)
        self.label_17.setObjectName(u"label_17")
        self.label_17.setGeometry(QRect(360, 50, 81, 16))
        self.label_18 = QLabel(self.frame_2)
        self.label_18.setObjectName(u"label_18")
        self.label_18.setGeometry(QRect(360, 70, 111, 16))
        self.label_19 = QLabel(self.frame_2)
        self.label_19.setObjectName(u"label_19")
        self.label_19.setGeometry(QRect(360, 90, 111, 16))
        self.label_20 = QLabel(self.frame_2)
        self.label_20.setObjectName(u"label_20")
        self.label_20.setGeometry(QRect(530, 30, 81, 16))
        self.label_21 = QLabel(self.frame_2)
        self.label_21.setObjectName(u"label_21")
        self.label_21.setGeometry(QRect(530, 90, 111, 16))
        self.label_22 = QLabel(self.frame_2)
        self.label_22.setObjectName(u"label_22")
        self.label_22.setGeometry(QRect(530, 70, 111, 16))
        self.label_23 = QLabel(self.frame_2)
        self.label_23.setObjectName(u"label_23")
        self.label_23.setGeometry(QRect(530, 50, 81, 16))
        self.label_3 = QLabel(self.centralwidget)
        self.label_3.setObjectName(u"label_3")
        self.label_3.setGeometry(QRect(20, 10, 31, 21))
        self.label_4 = QLabel(self.centralwidget)
        self.label_4.setObjectName(u"label_4")
        self.label_4.setGeometry(QRect(130, 10, 61, 21))
        self.lineEdit_def = QLineEdit(self.centralwidget)
        self.lineEdit_def.setObjectName(u"lineEdit_def")
        self.lineEdit_def.setEnabled(False)
        self.lineEdit_def.setGeometry(QRect(140, 400, 171, 24))
        self.lineEdit_def.setFrame(True)
        self.frame = QFrame(self.centralwidget)
        self.frame.setObjectName(u"frame")
        self.frame.setGeometry(QRect(10, 39, 561, 141))
        self.frame.setFrameShape(QFrame.Box)
        self.frame.setFrameShadow(QFrame.Raised)
        self.frame_5 = QFrame(self.frame)
        self.frame_5.setObjectName(u"frame_5")
        self.frame_5.setGeometry(QRect(300, 10, 171, 80))
        self.frame_5.setFrameShape(QFrame.NoFrame)
        self.frame_5.setFrameShadow(QFrame.Plain)
        self.radioButton = QRadioButton(self.frame_5)
        self.radioButton.setObjectName(u"radioButton")
        self.radioButton.setEnabled(True)
        self.radioButton.setGeometry(QRect(10, 20, 151, 22))
        self.radioButton.setChecked(True)
        self.radioButton_3 = QRadioButton(self.frame_5)
        self.radioButton_3.setObjectName(u"radioButton_3")
        self.radioButton_3.setEnabled(True)
        self.radioButton_3.setGeometry(QRect(10, 40, 151, 22))
        self.radioButton_3.setChecked(False)
        self.label_6 = QLabel(self.frame_5)
        self.label_6.setObjectName(u"label_6")
        self.label_6.setGeometry(QRect(10, 0, 31, 16))
        self.EvVText = QPlainTextEdit(self.centralwidget)
        self.EvVText.setObjectName(u"EvVText")
        self.EvVText.setGeometry(QRect(50, 50, 251, 70))
        self.comboBox = QComboBox(self.centralwidget)
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.setObjectName(u"comboBox")
        self.comboBox.setGeometry(QRect(350, 140, 131, 24))
        self.pushButton_3 = QPushButton(self.centralwidget)
        self.pushButton_3.setObjectName(u"pushButton_3")
        self.pushButton_3.setGeometry(QRect(330, 350, 61, 24))
        self.checkBox_2 = QCheckBox(self.centralwidget)
        self.checkBox_2.setObjectName(u"checkBox_2")
        self.checkBox_2.setGeometry(QRect(20, 400, 121, 22))
        self.checkBox_3 = QCheckBox(self.centralwidget)
        self.checkBox_3.setObjectName(u"checkBox_3")
        self.checkBox_3.setGeometry(QRect(20, 430, 151, 22))
        self.checkBox_4 = QCheckBox(self.centralwidget)
        self.checkBox_4.setObjectName(u"checkBox_4")
        self.checkBox_4.setGeometry(QRect(20, 460, 78, 22))
        self.checkBox = QCheckBox(self.centralwidget)
        self.checkBox.setObjectName(u"checkBox")
        self.checkBox.setGeometry(QRect(20, 350, 161, 22))
        self.checkBox.setChecked(True)
        self.progress = QProgressBar(self.centralwidget)
        self.progress.setObjectName(u"progress")
        self.progress.setGeometry(QRect(450, 530, 81, 16))
        self.progress.setValue(0)
        self.progress.setTextVisible(False)
        self.progress.setInvertedAppearance(False)
        self.progress_2 = QProgressBar(self.centralwidget)
        self.progress_2.setObjectName(u"progress_2")
        self.progress_2.setGeometry(QRect(260, 160, 81, 16))
        self.progress_2.setValue(0)
        self.progress_2.setTextVisible(False)
        self.progress_2.setInvertedAppearance(False)
        MainWindow.setCentralWidget(self.centralwidget)
        self.frame_3.raise_()
        self.frame_4.raise_()
        self.frame_2.raise_()
        self.frame.raise_()
        self.lineEdit.raise_()
        self.lineEdit_xs.raise_()
        self.lineEdit_el.raise_()
        self.pushButton.raise_()
        self.label_5.raise_()
        self.label_2.raise_()
        self.label_7.raise_()
        self.lineEdit_anh.raise_()
        self.pushButton_5.raise_()
        self.lineEdit_2.raise_()
        self.label_3.raise_()
        self.label_4.raise_()
        self.lineEdit_def.raise_()
        self.EvVText.raise_()
        self.comboBox.raise_()
        self.pushButton_3.raise_()
        self.checkBox_2.raise_()
        self.checkBox_3.raise_()
        self.checkBox_4.raise_()
        self.checkBox.raise_()
        self.progress.raise_()
        self.progress_2.raise_()
        self.menubar = QMenuBar(MainWindow)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 580, 21))
        self.menuplot = QMenu(self.menubar)
        self.menuplot.setObjectName(u"menuplot")
        self.menuload_data = QMenu(self.menubar)
        self.menuload_data.setObjectName(u"menuload_data")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.menubar.addAction(self.menuplot.menuAction())
        self.menubar.addAction(self.menuload_data.menuAction())
        self.menuplot.addAction(self.actionEV)
        self.menuload_data.addAction(self.actionSUMMARY)
        self.menuload_data.addAction(self.actionOUTCAR)
        self.menuload_data.addAction(self.actionDOSCAR)

        self.retranslateUi(MainWindow)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"debyetools GUI (lite)", None))
        self.actionE_V.setText(QCoreApplication.translate("MainWindow", u"Exxx", None))
        self.actionasasas.setText(QCoreApplication.translate("MainWindow", u"asasas", None))
        self.actionEV.setText(QCoreApplication.translate("MainWindow", u"E(V)", None))
        self.actionSUMMARY.setText(QCoreApplication.translate("MainWindow", u"Energy curve (SUMMARY)", None))
        self.actionOUTCAR.setText(QCoreApplication.translate("MainWindow", u"Elastic constants (OUTCAR)", None))
        self.actionDOSCAR.setText(QCoreApplication.translate("MainWindow", u"eDOS (DOSCAR.i)", None))
        self.lineEdit.setText(QCoreApplication.translate("MainWindow", u"0.02698", None))
        self.lineEdit_xs.setText(QCoreApplication.translate("MainWindow", u"0, 0, 0", None))
        self.lineEdit_el.setText(QCoreApplication.translate("MainWindow", u"0, 0, 0, 0", None))
        self.pushButton.setText(QCoreApplication.translate("MainWindow", u"fit", None))
        self.label_5.setText(QCoreApplication.translate("MainWindow", u"EOS params:", None))
        self.label_2.setText(QCoreApplication.translate("MainWindow", u"E(V):", None))
        self.label_7.setText(QCoreApplication.translate("MainWindow", u"Stiffness Tensor (GPa)", None))
        self.lineEdit_anh.setText(QCoreApplication.translate("MainWindow", u"0, 1", None))
        self.pushButton_5.setText(QCoreApplication.translate("MainWindow", u"calculate", None))
        self.lineEdit_2.setText(QCoreApplication.translate("MainWindow", u"-3e5, 1e-5, 7e10, 4", None))
        self.pushButton_2.setText(QCoreApplication.translate("MainWindow", u"re-calculate Poisson's ratio", None))
        self.label_9.setText(QCoreApplication.translate("MainWindow", u"B (Voigt):", None))
        self.lineEdit_4.setText(QCoreApplication.translate("MainWindow", u"78", None))
        self.label_10.setText(QCoreApplication.translate("MainWindow", u"B (Reuss):", None))
        self.lineEdit_5.setText(QCoreApplication.translate("MainWindow", u"78", None))
        self.label_11.setText(QCoreApplication.translate("MainWindow", u"B (Voigt-Reuss-Hill):", None))
        self.lineEdit_6.setText(QCoreApplication.translate("MainWindow", u"78", None))
        self.elastic_constants.setHtml(QCoreApplication.translate("MainWindow", u"<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><meta charset=\"utf-8\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"hr { height: 1px; border-width: 0; }\n"
"li.unchecked::marker { content: \"\\2610\"; }\n"
"li.checked::marker { content: \"\\2612\"; }\n"
"</style></head><body style=\" font-family:'Segoe UI'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">97  69  69  0   0   0</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">69  97  69  0   0   0</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">69  69  97  0   0   0</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-r"
                        "ight:0px; -qt-block-indent:0; text-indent:0px;\">0   0   0   45  0   0</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">0   0   0   0   45  0</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">0   0   0   0   0   45</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>", None))
        self.lineEdit_3.setText(QCoreApplication.translate("MainWindow", u"0.34", None))
        self.label_8.setText(QCoreApplication.translate("MainWindow", u"Poisson's ratio:", None))
        self.label_12.setText(QCoreApplication.translate("MainWindow", u"S (Voigt):", None))
        self.label_13.setText(QCoreApplication.translate("MainWindow", u"S (Reuss):", None))
        self.lineEdit_7.setText(QCoreApplication.translate("MainWindow", u"28", None))
        self.label_14.setText(QCoreApplication.translate("MainWindow", u"S (Voigt-Reuss-Hill):", None))
        self.lineEdit_8.setText(QCoreApplication.translate("MainWindow", u"33", None))
        self.lineEdit_9.setText(QCoreApplication.translate("MainWindow", u"24", None))
        self.lineEdit_10.setText(QCoreApplication.translate("MainWindow", u"1.8", None))
        self.label_15.setText(QCoreApplication.translate("MainWindow", u"Universal anisotrpy:", None))
        self.label_16.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        self.label_17.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        self.label_18.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        self.label_19.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        self.label_20.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        self.label_21.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        self.label_22.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        self.label_23.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        self.label_3.setText(QCoreApplication.translate("MainWindow", u"mass:", None))
        self.label_4.setText(QCoreApplication.translate("MainWindow", u"kg/mol-at", None))
        self.lineEdit_def.setText(QCoreApplication.translate("MainWindow", u"100, 1, 1000, 0.1", None))
        self.radioButton.setText(QCoreApplication.translate("MainWindow", u"eV and A^3 (per at)", None))
        self.radioButton_3.setText(QCoreApplication.translate("MainWindow", u" J and m^3 (per mol-at)", None))
        self.label_6.setText(QCoreApplication.translate("MainWindow", u"units:", None))
        self.EvVText.setPlainText(QCoreApplication.translate("MainWindow", u"#V	E\n"
"1.201468E+01	-3.210751E+00\n"
"1.241964E+01	-3.326448E+00\n"
"1.283359E+01	-3.424838E+00\n"
"1.325664E+01	-3.507320E+00\n"
"1.368889E+01	-3.575208E+00\n"
"1.413044E+01	-3.629742E+00\n"
"1.458137E+01	-3.672073E+00\n"
"1.504180E+01	-3.703298E+00\n"
"1.551183E+01	-3.724441E+00\n"
"1.599154E+01	-3.736464E+00\n"
"1.648104E+01	-3.740270E+00\n"
"1.698044E+01	-3.736691E+00\n"
"1.748982E+01	-3.726524E+00\n"
"1.800928E+01	-3.710495E+00\n"
"1.853893E+01	-3.689294E+00\n"
"1.907887E+01	-3.663562E+00\n"
"1.962919E+01	-3.633908E+00\n"
"2.018999E+01	-3.600914E+00\n"
"2.076137E+01	-3.565133E+00\n"
"2.134343E+01	-3.527076E+00\n"
"2.193627E+01	-3.487192E+00", None))
        self.comboBox.setItemText(0, QCoreApplication.translate("MainWindow", u"Birch-Murnaghan", None))
        self.comboBox.setItemText(1, QCoreApplication.translate("MainWindow", u"Rose-Vinet", None))
        self.comboBox.setItemText(2, QCoreApplication.translate("MainWindow", u"Mie-Gruneisen", None))
        self.comboBox.setItemText(3, QCoreApplication.translate("MainWindow", u"TB-SMA", None))
        self.comboBox.setItemText(4, QCoreApplication.translate("MainWindow", u"Murnaghan", None))
        self.comboBox.setItemText(5, QCoreApplication.translate("MainWindow", u"Poirier-Tarantola", None))
        self.comboBox.setItemText(6, QCoreApplication.translate("MainWindow", u"EAM int. potential", None))
        self.comboBox.setItemText(7, QCoreApplication.translate("MainWindow", u"Morse int. potential", None))

        self.pushButton_3.setText(QCoreApplication.translate("MainWindow", u"calculate", None))
        self.checkBox_2.setText(QCoreApplication.translate("MainWindow", u"mono-vacancies:", None))
        self.checkBox_3.setText(QCoreApplication.translate("MainWindow", u"explicit anh.:", None))
        self.checkBox_4.setText(QCoreApplication.translate("MainWindow", u"excess:", None))
        self.checkBox.setText(QCoreApplication.translate("MainWindow", u"electronic contribution:", None))
        self.menuplot.setTitle(QCoreApplication.translate("MainWindow", u"plot", None))
        self.menuload_data.setTitle(QCoreApplication.translate("MainWindow", u"load data", None))
    # retranslateUi

